import os
import time

from rio_metrics.collector import HTTPMetricsCollector, IOMetricsProtocol

IO_METRICS_HOST = os.environ.get('IO_METRICS_HOST', 'localhost')
IO_METRICS_UDP_PORT = int(os.environ.get('IO_METRICS_UDP_PORT', '8092'))
IO_METRICS_HTTP_PORT = int(os.environ.get('IO_METRICS_HTTP_PORT', '8093'))
IO_METRICS_PROTOCOL = os.environ.get('IO_METRICS_PROTOCOL', 'udp')


class HTTPMetricsMiddleware:
    def __init__(self, get_response):
        self.get_response = get_response

        port = IO_METRICS_UDP_PORT
        if IO_METRICS_PROTOCOL == IOMetricsProtocol.HTTP.value:
            port = IO_METRICS_HTTP_PORT
        self.collector = HTTPMetricsCollector(IO_METRICS_PROTOCOL, IO_METRICS_HOST, port)

    def __call__(self, request):
        start_time = time.time()
        response = self.get_response(request)
        self.collector.collect(duration=time.time() - start_time,
                               method=request.method, path=request.path,
                               code=response.status_code)
        return response



from setuptools import setup

with open('README.md', encoding='utf-8') as f:
    long_desc = f.read()

setup(
    name='django-riometrics-middleware',
    version='1.0.1',
    description='Rapyuta.io Metrics Django Middleware',
    long_description=long_desc,
    long_description_content_type='text/markdown',
    author='Rapyuta Robotics',
    author_email='opensource@rapyuta-robotics.com',
    packages=['rio_metrics'],
    python_requires='>=3.6',
    license='Apache 2.0',
    install_requires=[
        'requests>=2.20.0',
        'urllib3>=1.23',
        'pytelegraf==0.3.3',
        'setuptools'
    ],
)
